pub struct PoissonConfig {
pub iso_level: f32,
pub depth: u32,
pub prune_depth: u32,
pub full_depth: u32,
pub scale: f32,
pub samples_per_node: f32,
pub confidence: bool,
pub output_density: bool,
pub cg_depth: u32,
}Expand description
Configuration parameters for Poisson reconstruction
Fields
iso_level: f32Isosurface extraction level (default: 0.0)
depth: u32The maximum depth of the octree (default: 8)
prune_depth: u32The minimum depth at which the octree will be pruned (default: 5)
full_depth: u32The maximum depth at which the octree will be simplified (default: 10)
scale: f32Scale factor for the importance of point positions vs normals (default: 1.1)
samples_per_node: f32The number of samples to use for density estimation (default: 1.0)
confidence: boolWhether to use confidence weighting (default: false)
output_density: boolWhether to output density information (default: false)
cg_depth: u32Number of gauss-seidel relaxations to be performed at each level (default: 8)